;; GRASP World (formerly 'NORM-VALUE ARENA') 2018
;; Gert Jan Hofstede
;; Revised: Chutao Liu
;;
;; 2018 04 09 GJH: prepared for conference SSC Stockholm, in association with paper; see info tab
;; 2018 05 26 CL:  modified according to SSC reviewers' suggestion.
;;

globals [
  colors-in-use                         ;; list of colors that mark each group.
  fights                                ;; count of fights this tick.
  groups                                ;; count of groups on the ground.
]

breed [ auras aura ]
breed [ people person ]

people-own [
  my-aura                               ;; aura color permanently indicates my group.
  my-shade                              ;; norm meme.
  my-mate                               ;; the person with whom one exchanges status.
  my-emotion                            ;; can be one of three: angry, happy, neutral.
  status                                ;; variable 'war leadership' after exchanges.
  alone?                                ;; with or without a group?
  can-play?                             ;; free to start playing in a dyad?
  ticks-in-group                        ;; age counter for a person's group membership.
  already?                              ;; whether his group has already been chosen to decide to stay or leave.
  leave?                                ;; may the person leave the group? decided by both self-feeling and entitlement.
  ]

auras-own [
  my-person                             ;; person that owns this aura.
  ]

patches-own [
  occupied?                             ;; whether one of the assigned gathering points has been used by another group.
  patch-color                           ;; the color of the assigned gathering point, which is the same as the group who occupies it.
]

to setup
  clear-all
  if new-seed? [ set current-seed new-seed ]
  random-seed current-seed
  setup-patches
  setup-turtles
  reset-ticks
end

to setup-patches
  ask patches [ set pcolor green + 2 ]
  ask patches [ set occupied? false ]                      ;; at the start, no gathering point is occupied.
  ask patches [ set patch-color white ]
end

to setup-turtles
  let shades-total n-of number-shades [81 82 83 84 85 86 87 88 89]
  create-people number-people
  [
    setxy random-xcor random-ycor
    move-to patch-here                                     ;; move to the center of the patch.
    let possible-color one-of shades-total                 ;; shades of cyan; denotes the person's norm.
    set color possible-color
    set my-shade possible-color mod 10                     ;; make the person's shade scaled.
    set my-mate nobody
    set alone? true
    set can-play? true
    set shape "face neutral"
    set status random-normal 0.5 initial-status-stdev      ;; normal distribution.
    set size 1 + status                                    ;; higher status makes turtle bigger.
    if label-turtles? [ set label who ]                    ;; for tracing who is who.
    set ticks-in-group 0
  ]
  create-auras number-people
  [
    set shape "circle"
    set color grey                                         ;; my person is alone.
    let person-size 0
    let person-patch patch 0 0
    let aura-person nobody
    ask person (who - number-people)                       ;; that's my person. who refers to aura's own number.
    [ set aura-person self                                 ;; self is simply "me", here refers to the selected person.
      set my-aura myself                                   ;; myself is "the agent who asked me to do what i am doing now", here refers to the newly created aura.
      set person-size size                                 ;; size of person is now in local variable, making it available to use later in the code.
      set person-patch patch-here
    ]
    set my-person aura-person
    move-to person-patch
    set size person-size * 1.3                             ;; to create the aura larger than the person in size.
   ]

  set colors-in-use remove-duplicates [color] of auras     ;; creates list with used turtle colors. all auras' colors are listed so remove-duplicate keep only one color one time without repetition.
end

to init-tick
  set fights 0
  ask people [
    call-aura                                              ;; Make those lonely people's aura from last tick back to normal size again.
    set already? false                                     ;; no group has been chosen to decide stay or leave.
    set leave? false                                       ;; all members in group do not leave the group at the beginning.
    set can-play? true                                     ;; mate-ship ends per tick, so at the beginning everyone is open for dyadic engagement.
  ]
end

to end-tick                                                ;; reset for next tick.
  set colors-in-use remove-duplicates [color] of auras     ;; for plot the number of groups.
  set colors-in-use filter [i -> i != 5] colors-in-use     ;; grey color is used to mark lonely people, not considered to be a group mark.
  set groups length colors-in-use
  ask people [
    set size 1 + status                                    ;; resize agents to show their relative status.
    call-aura
    if alone? [ ask my-aura                                ;; lonely people have small (invisible) aura, making them eaiser to identify on ground.
      [set size 0.5 ] ]
  ]
end

to go
  init-tick
  ask people [                                             ;; ask 1: Are you alone?
    if alone? [                                              ;; you may be alone at session start, after fleeing, or after your last mate fled.
      look-for-group                                         ;; if alone, look for group; else play and possibly quarrel. After having a group, aura gets group color.
    ]
  ]
  ask people [                                             ;; ask 2: Can you play?
    if not alone? [                                          ;; you may have found a friend or group and no longer be alone.
      if can-play? [                                         ;; can-play? true if not in a dyad yet, or finished playing. This is to make sure that one agent just play once per tick.
        pick-playmate-in-group                               ;; here you approach another agent from your color group. if you find a playmate, you both set can-play? false until end of tick.
        if my-mate != nobody [                               ;; I found a playmate. else you stay in the group and wait for next tick.
          play
        ]
      ]
    ]
  ]
  ask people [                                             ;; ask 3: Will you stay?
    decide-leave-or-not
    let my-aura-color grey
    ask my-aura [
      set my-aura-color color                              ;; the person set the color of its aura as the person's group identity.
    ]
    ifelse alone? or not any? other auras with [ color = my-aura-color ] [
      stay-alone-this-tick                                 ;; I have no group or be the last.
    ][
      set ticks-in-group ticks-in-group + 1                ;; I am in a group. Group time starts to count.
    ]
  ]
  end-tick
  tick
end

to look-for-group                                          ;; turtle (people) procedure for people with alone?
  let our-color 1
  let nearby-people other people with [distance myself < 32 ]
    ifelse any? nearby-people [                            ;; map size is 33*33, so distance 32 means one person can reach anyone on the ground. Space is not an obstacle in this model.
      set alone? false                                     ;; I can always join, so alone? will now become false. even if they are playing I can join their group.
      ask one-of nearby-people [
         if alone? [
            set alone? false
            pick-color                                     ;; this person is alone; new group formed with new aura color.
            pick-gathering-point
            set ticks-in-group 1
         ]
      ask my-aura [ set our-color color ]                  ;; set friends' aura as the group color. Join his or her group.
      ]
      ask my-aura [ set color our-color]                   ;; now my aura can copy his aura's color and I am part of that group.
      join-the-group
      set ticks-in-group 1
   ][
   stay-alone-this-tick
   ]
end

to pick-color                                              ;; turtle (people) procedure. Newly formed group pick a new color as group ID.
  let my-new-group-color orange                            ;; start with a non-grey color.
  while [ member? my-new-group-color colors-in-use ] [     ;; pick any color but grey that's unused. when new color is selected, the member? shows false and the loop is broken. New color then get registered.
    set my-new-group-color one-of [orange red brown yellow green lime turquoise cyan sky blue violet magenta pink 37 47 97 107 127 13 33 43 123]
  ]
  ask my-aura [ set color my-new-group-color ]             ;; In theory, colors listed above are enough for 44 players (22 colors, minimun 2 players per group).
  set colors-in-use remove-duplicates [color] of auras     ;; update colors-in-use.
end

to pick-gathering-point                                    ;; turtle (people) procedure. Based on pre-assigned gathering patches, new group forms and gathers around certain point, thus avoid mingle with each other.
  let our-color orange
  ask my-aura [ set our-color color ]
  let candidate-points (patch-set patch 0 0)
  ifelse number-people > 31 [
    set candidate-points (patch-set patch 0 0 patch 0 6 patch 0 12 patch 0 -6 patch 0 -12 patch 6 0 patch 6 6 patch 6 12 patch 6 -6 patch 6 -12 patch 12 0 patch 12 6 patch 12 12   ;; use 5*5=25 gathering points
      patch 12 -6 patch 12 -12 patch -6 0 patch -6 6 patch -6 12 patch -6 -6 patch -6 -12 patch -12 0 patch -12 6 patch -12 12 patch -12 -6 patch -12 -12)
  ][
    ifelse number-people > 17 [                                                                                                                                                     ;; use 4*4=16 gathering points
      set candidate-points (patch-set patch 4 4 patch 4 12 patch 4 4 patch 4 -4 patch 4 -12 patch 12 4 patch 12 12 patch 12 -4 patch 12 -12
        patch -4 4 patch -4 12 patch -4 -4 patch -4 -12 patch -12 4 patch -12 12 patch -12 -4 patch -12 -12)
    ][
      set candidate-points (patch-set patch 0 0 patch 10 10 patch 10 -10 patch -10 10 patch 0 10 patch 10 0 patch 0 -10 patch -10 0 patch -10 -10)                                  ;; use 3*3=9  gathering points
    ]
  ]
  let target one-of candidate-points with [occupied? = false]
  ifelse target != nobody [                                   ;; serve as an insurance for no available places.
    let how-far distance target
    while [ how-far > neighbour-distance] [                   ;; while loop makes agents gradually move to the gathering point, or do not move if close enough, thus prevent constantly move within group.
      face target
      advance
      set how-far distance target
    ]
    call-aura
    ask target [ set patch-color our-color ]                  ;; make the gathering point coloful, so later comers can easily move to here (This point is for this group for now!).
    ask target [ set occupied? true ]                         ;; occupy this point so other groups can not take it, prevent overcrowding to a certain extent (Hey, pick another point for another group).
  ][
    let place-for-now (patch-set patch 0 16 patch 16 0 patch -16 0 patch 0 -16)    ;; if no place of the assigned gathering points is available, then have one of four temporaril places to go.
    let place-to-go one-of place-for-now with [occupied? = false]
    let place-how-far distance place-to-go
    while [ place-how-far > neighbour-distance] [
      face place-to-go
      advance
      set place-how-far distance place-to-go
    ]
    call-aura
    ask place-to-go [ set patch-color our-color ]
    ask place-to-go [ set occupied? true ]
  ]
end

to join-the-group                                            ;; turtle (people) procedure. People who join an existing group need to go to the group gathering point.
  let our-color orange
  ask my-aura [ set our-color color ]
  let target one-of patches with [patch-color = our-color]
  let how-far distance target
  while [ how-far > neighbour-distance] [
    face target
    advance
    set how-far distance target
    let crowds count people in-radius neighbour-distance
    if crowds > 1 [                                          ;; Detect whether neighbourhood is too crowded. If so, simply move to another patch or randomly move a bit more, depending on the switch.
      ifelse number-people < 31 [                            ;; 2 options: move to a patch nearby / move a bit further with random distance and direction.
        let comfort-zone patches in-radius neighbour-distance with [not any? people-here]
        if any? comfort-zone [move-to one-of comfort-zone]   ;; Prevent constantly finding a place and thus hold the process.
      ][
        rt (45 + random 45)
        fd neighbour-distance
      ]
    ]
  ]
  call-aura
end

to advance                                                   ;; turtle (people) procedure.
  rt random 60                                               ;; create some stocasticity so will not all move to one direction. Help to prevent over-crowding.
  if can-move? 1 [
  fd 1
  call-aura
  ]
end

to call-aura                                                 ;; turtle (people) procedure.
  ifelse number-people < 31 [
    let person-patch patch-here
    ask my-aura [ move-to person-patch]                      ;; ask aura to be at the patch (first comer in behind).
    move-to patch-here                                       ;; ask person to be at the patch (later comer in front).
    let my-size size
    let my-ticks-in-group ticks-in-group
    ask my-aura [
      set size my-size * ( 1.1 + (my-ticks-in-group) / 50 )  ;; the longer one person stay in a group, the larger the aura is.
      if size > 2.1 * my-size [
        set size 2.1 * my-size
      ]
    ]
  ][                                                         ;; when there are too many people, move to coordinates instead of patches to prevent overcrowding.
    let person-xcor xcor
    let person-ycor ycor
    ask my-aura [ setxy person-xcor person-ycor ]            ;; ask aura to be at the coordinates (first comer in behind).
    setxy xcor ycor                                          ;; ask person to be at the coordinates (later comer in front).
    let my-size size
    let my-ticks-in-group ticks-in-group
    ask my-aura [
      set size my-size * ( 1.1 + (my-ticks-in-group) / 50 )  ;; the longer one person stay in a group, the larger the aura is.
      if size > 2.1 * my-size [
        set size 2.1 * my-size
      ]
    ]
  ]
end

to pick-playmate-in-group                                                                        ;; turtle (people) procedure.
  let mate nobody                                                                                ;; create a local variable.
  let group-color 1
  ask my-aura [ set group-color color ]                                                          ;; group gets color of my-aura.
  let my-who who
  let my-group-members people with [ who = my-who ]                                              ;; that's only me for now.
  let my-group-auras auras with [ color = group-color ]                                          ;; that's with my aura's color.
  ask my-group-auras [
    set my-group-members (turtle-set my-person my-group-members)                                 ;; each aura adds its person to my-group-members.
  ]
  ifelse any? other people with [can-play? and member? self my-group-members] [
    ask one-of other people with [can-play? and member? self my-group-members ] [                ;; choose a random playmate from my group.
      set mate self                                                                              ;; he gives himself as local var 'mate'.
      set my-mate myself                                                                         ;; he makes me, the caller, his my-mate.
      set can-play? false
    ]
    set my-mate mate                                                                             ;; you take him as your my-mate.
    set can-play? false
  ]
  []                                                                                             ;; be in a group, but do not play with anyone this tick. Try again next tick.
end

to play                                                                                          ;; turtle (people) procedure. mutual status conferral.
  let status-conferral  0
  let status-affront  0                                                                          ;; how much bigger was my conferral than yours.
  let mate-status-conferral 0
  let mate-status 0                                                                              ;; local variable.
  let mate-shade 1
  set my-emotion "happy"                                                                         ;; I'm in a playful mood.
  make-face
  set status-conferral (random-normal 0.5 status-conferral-stdev)
  ask my-mate [
    set mate-status status
    set my-emotion "happy"                                                                       ;; he is in the mood for playing.
    make-face
    set mate-status-conferral (random-normal 0.5 status-conferral-stdev)                         ;; he replicates a status conferral.
    set mate-shade my-shade
  ]

  let norm-misunderstanding xenophobia-factor * (abs (my-shade - mate-shade))                    ;; establish norm misunderstanding.

  let dyadic-trust 0                                                                             ;; dyadic trust: in groups that sustain longer, people are less affronted when play with each other.
  let my-time-in-group ticks-in-group
  let mate-time-in-group [ticks-in-group] of my-mate
  if my-time-in-group >= 10 [set my-time-in-group 10]
  if mate-time-in-group >= 10 [set mate-time-in-group 10]
  let time-know-each-other min (list my-time-in-group mate-time-in-group)                        ;; shortest in-group time determines how long know each other.



  set status-affront status-conferral - mate-status-conferral                                    ;; how much I was nicer than my mate, so he owes me.
  let submission power-distance / 100 * ( mate-status - status )                                 ;; power distance makes me likely to accept status deficit from the more statusful.
  set status-affront status-affront - submission                                                 ;; less affront due to submission caused by power distance.
  let my-perceived-status-affront status-affront + norm-misunderstanding - dyadic-trust          ;; misunderstanding makes both think the other was less nice, and so I was nicer.
  let mate-perceived-status-affront (-1 * status-affront) + norm-misunderstanding - dyadic-trust

                                                                                                 ;; now check whether one of us is really angry.

  ifelse my-perceived-status-affront > status-deficit-limit or mate-perceived-status-affront > status-deficit-limit [     ;; over the limit and choose to fight.
    if my-perceived-status-affront > status-deficit-limit [
      set my-emotion "angry"                                                                     ;; I pick a fight.
    ]
    if mate-perceived-status-affront > status-deficit-limit [
      ask my-mate [
        set my-emotion "angry"                                                                   ;; mate picks a fight.
      ]
    ]
    set fights fights + 1
    let our-color color
    let my-power-conferral my-perceived-status-affront * status * ( 1 / 200 )
    let mate-power-conferral mate-perceived-status-affront * mate-status * ( 1 / 200 )
    ifelse my-power-conferral >= mate-power-conferral [
      win
      ask my-mate [ lose ]
    ][
      lose
      ask my-mate [ win ]
    ]                                                                                            ;; end of fight.
  ][                                                                                             ;; else of fight, one of us is displeased.

  ifelse my-perceived-status-affront > 0.5 * status-deficit-limit or mate-perceived-status-affront > 0.5 * status-deficit-limit [
    if my-perceived-status-affront > 0.5 * status-deficit-limit [
    set my-emotion "neutral"                                                                     ;; I lose my good mood, but do not fight.
    ]
    if mate-perceived-status-affront > 0.5 * status-deficit-limit [
      ask my-mate [
       set my-emotion "neutral"
       ]
    ]
  ]
  []                                                                                             ;; nothing happens if the affront is < 0.5 * limit, both people are happy.
  ]

  ask my-mate [                                                                                  ;; the exchange ends here.
     make-face                                                                                   ;; whatever emotions (s)he picked up.
     set my-mate nobody                                                                          ;; mate-ship also ends after the play.
  ]
  make-face
  set my-mate nobody
end

to make-face                                                                                     ;; turtle (people) procedure.
  ask people [
    ifelse my-emotion = "angry" [ set shape "face angry"] [
      ifelse my-emotion = "happy" [ set shape "face happy"] [
        ifelse my-emotion = "sad" [ set shape "face sad"] [
          set shape "face neutral"]
      ]
    ]
  ]
end

to win                                                                                          ;; turtle (people) procedure.
  set my-emotion "happy"
  set status status * ( 1 + win-bonus)
  if status > 1 [ set status 1 ]
  make-face
end

to lose                                                                                         ;; turtle (people) procedure.
  set my-emotion "angry"
  set status status * ( 1 - win-bonus)
  if status < 0 [ set status 0 ]
  make-face
  face my-mate                                                                                  ;; prepare to flee if needed, but do not move instantly.
end

to decide-leave-or-not                                                                          ;; turtle (people) procedure.
  if not already? and not alone? [                                                              ;; I am a group member and my group has not been chosen to go through this process.
    let allow? false                                                                            ;; the bigshot (group member with highest status) does not decide yet, so no one is allowed to leave.
    let my-who who
    let my-group-auras nobody
    ask my-aura [
      set my-group-auras other auras with
      [color = [color] of myself and color != grey]                                             ;; != grey prevent single agents to form a group with color grey.
    ]                                                                                           ;; make turtle-set of all turtles whose auras are in my-group-auras.
    let my-group-members people with [ who = my-who ]                                           ;; I am a member.
    ask my-group-auras [                                                                        ;; ask other auras in my group to add their people to my group.
      set my-group-members (turtle-set my-person my-group-members)
    ]
    ask my-group-members [ set already? true ]                                                  ;; decision will be made for this group with all members. Prevent reselecting the member of this group.
    let my-happy-group-members my-group-members with [ my-emotion = "happy" ]
    let my-unhappy-group-members my-group-members with [ my-emotion != "happy" ]

    let my-status [ status ] of self                                                            ;; "allow" takes effect here by first select a bigshot in the group.
    let my-group-bigshot self
    let my-group-ordinary turtle-set nobody
    set my-group-bigshot max-one-of my-group-members [ status ]                                 ;; select a bigshot that has the highest status in the group, always move first.
    set my-group-ordinary turtle-set my-group-members with [self != my-group-bigshot]           ;; others will be ordinary in the group, move after bigshot has moved.
    let max-status-in-my-group [ status ] of my-group-bigshot

    ask my-group-bigshot [                                                                      ;; bigshot always moves first.
      ifelse count my-group-members <= 1 [                                                      ;; as double sure no single players go through the following group process.
        stop-group
      ][
        ifelse my-emotion = "angry" [
          ifelse random 50 < individualism and count my-happy-group-members < (individualism / 75) * count my-group-members [
            set allow? true                                                                     ;; by leaving, bigshot allows ordinary in the group to leave as they want later.
            leave-group                                                                         ;; leaving does not mean dismissing the group, others can still stay as a group based on their choices.
          ][]                                                                                   ;; otherwise, just stay (do nothing), ticks will be counted later, no hurry now.
        ][
          ifelse my-emotion = "neutral" [
            ifelse random 75 < individualism and count my-happy-group-members < (individualism / 125) * count my-group-members [  ;; more things to consider -- group atmosphere.
              set allow? true
              leave-group
            ][]
          ][
            if my-emotion = "happy" [
              ifelse random 100 < individualism and count my-happy-group-members < (individualism / 200) * count my-group-members [   ;; more things to consider -- group atmosphere.
                set allow? true
                leave-group
              ][]
    ]]]]]

    ask my-group-ordinary [                                                                     ;; after bigshot has moved, ordinary in the group decide whether to stay or to leave.
      ifelse count my-group-members <= 1 [
        stop-group                                                                              ;; stop the group if I am the only one left.
      ][                                                                                        ;; first: do I feel like leaving ?
        ifelse my-emotion = "angry" [
          ifelse random 50 < individualism and count my-happy-group-members < (individualism / 75) * count my-group-members [ ;; the same judgment standard as the bigshot.
            set leave? true                                                                     ;; pull the first trigger.
          ][]
        ][
          ifelse my-emotion = "neutral" [
            ifelse random 75 < individualism and count my-happy-group-members < (individualism / 125) * count my-group-members [
              set leave? true
            ][]
          ][
            if my-emotion = "happy" [
              ifelse random 100 < individualism and count my-happy-group-members < (individualism / 200) * count my-group-members [
                set leave? true
              ][]
      ]]]]

      if not allow? [                                                                           ;; second: am I entitled to leave? If bigshot leaves, then ordinary can leave without this consideration.
        if max-status-in-my-group - my-status > (1 - power-distance / 100) [                    ;; If bigshot does not leave, ordinary have to overcome the power-distance and status difference to leave.
          set leave? false                                                                      ;; if power-distance is too large, then almost not possible to leave, unless not much status difference from bigshot.
        ]
      ]
      if leave? [leave-group]                                                                   ;; two triggers are pulled, leave the group.
    ]
  ]
end


to walk-away                                                                                    ;; turtle (people) procedure.
  rt 90 + random 180
  ifelse can-move? 16
  [ fd 16
    call-aura
  ][
    move-to one-of patches with [ not any? people-here and sum [count turtles-here] of neighbors = 0 ]
    call-aura
  ]
end

to leave-group                                                                                  ;; turtle (people) procedure.
  let my-who who
  let my-group-auras nobody
  ask my-aura [
    set my-group-auras other auras with
      [ color = [ color] of myself and color != grey]
  ]
  let my-group-members people with [ who = my-who ]
  ask my-group-auras [
    set my-group-members (turtle-set my-person my-group-members)                                ;; get all my group members.
  ]
  ifelse count my-group-members <= 2 [                                                          ;; if there are only 2 members left (include me) before I am leaving, then after I leave the group stops.
    face min-one-of my-group-members [distance myself]
    stop-group
  ][
  face min-one-of my-group-members [distance myself]                                            ;; otherwise, just leave the group without disturb it.
  set alone? true
  ask my-aura [set color grey]
  walk-away
  ]
end

to stop-group                                                                                   ;; turtle (people) procedure: I make my group dismissed.
  let our-color orange
  let my-who who
  let my-group-auras nobody
  ask my-aura [
    set our-color color
    set my-group-auras other auras with
      [ color = [ color] of myself and color != gray]
  ]
  ask patches with [patch-color = our-color] [                                                  ;; before stopping the group, clear the gathering point, so other groups can use them.
    set patch-color white                                                                       ;; this color is not used by any group, so will not interfere with turtle procedures.
    set occupied? false
  ]
  let my-group-members people with [ who = my-who ]
  ask my-group-auras [
    set my-group-members (turtle-set my-person my-group-members)
  ]
  ask my-group-members [                                                                        ;; ask all members to stay alone, thus dismiss the group.
    stay-alone-this-tick
  ]
end

to stay-alone-this-tick                                                                         ;; turtle (people) procedure.
  set alone? true
  make-face
  set ticks-in-group 0                                                                          ;; clear the ticks in group.
  ask my-aura [ set color grey ]
  walk-away
end

;;
;; Main coding structure finishes here.
;;

;;
;; Below is for experimental data gathering.
;;

to-report group-life-length
  let total-longevity 0
  foreach colors-in-use [c -> let group-longevity (max ([ticks-in-group] of people with [[color] of my-aura = c])) set total-longevity (total-longevity + group-longevity)]
  ifelse length colors-in-use != 0 [
    let mean-longevity (total-longevity / length colors-in-use)
    report mean-longevity
  ][
    let mean-longevity "no group"
    report mean-longevity
  ]
end

to-report status-differentiation
  let maximum-status [status] of max-one-of people [status]
  let minimum-status [status] of min-one-of people [status]
  report (maximum-status - minimum-status)
end

to-report happy-percent-in-group
  let total-happy-percent 0
  foreach colors-in-use [c -> let group-happy-percent ((count people with [[color] of my-aura = c and my-emotion = "happy"]) / (count people with [[color] of my-aura = c])) set total-happy-percent (total-happy-percent + group-happy-percent)]
  ifelse length colors-in-use != 0 [
    let mean-happy-percent (total-happy-percent / length colors-in-use)
    report mean-happy-percent
  ][
    let mean-happy-percent "no group"
    report mean-happy-percent
  ]
end

to-report neutral-percent-in-group
  let total-neutral-percent 0
  foreach colors-in-use [c -> let group-neutral-percent ((count people with [[color] of my-aura = c and my-emotion = "neutral"]) / (count people with [[color] of my-aura = c])) set total-neutral-percent (total-neutral-percent + group-neutral-percent)]
  ifelse length colors-in-use != 0 [
    let mean-neutral-percent (total-neutral-percent / length colors-in-use)
    report mean-neutral-percent
  ][
    let mean-neutral-percent "no group"
    report mean-neutral-percent
  ]
end

to-report angry-percent-in-group
  let total-angry-percent 0
  foreach colors-in-use [c -> let group-angry-percent ((count people with [[color] of my-aura = c and my-emotion = "angry"]) / (count people with [[color] of my-aura = c])) set total-angry-percent (total-angry-percent + group-angry-percent)]
  ifelse length colors-in-use != 0 [
    let mean-angry-percent (total-angry-percent / length colors-in-use)
    report mean-angry-percent
  ][
    let mean-angry-percent "no group"
    report mean-angry-percent
  ]
end

to-report std-of-shades-in-group
  let total-std 0
  foreach colors-in-use [c -> let group-std (standard-deviation ([color] of people with [[color] of my-aura = c])) set total-std (total-std + group-std)]
  ifelse length colors-in-use != 0 [
    let mean-std (total-std / length colors-in-use)
    report mean-std
  ][
    let mean-std "no group"
    report mean-std
  ]
end

to-report std-of-status-in-group
  let total-std 0
  foreach colors-in-use [c -> let group-std (standard-deviation ([status] of people with [[color] of my-aura = c])) set total-std (total-std + group-std)]
  ifelse length colors-in-use != 0 [
    let mean-std (total-std / length colors-in-use)
    report mean-std
  ][
    let mean-std "no group"
    report mean-std
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
369
10
905
547
-1
-1
16.0
1
10
1
1
1
0
0
0
1
-16
16
-16
16
1
1
1
ticks
30.0

BUTTON
213
36
276
69
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
213
73
276
106
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

SWITCH
192
514
364
547
label-turtles?
label-turtles?
1
1
-1000

PLOT
910
287
1147
423
emotion totals
ticks
n
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"neutral" 1.0 0 -4539718 true "" "plot count turtles with [shape = \"face neutral\" or shape = \"girl neutral\"]"
"angry" 1.0 0 -8053223 true "" "plot count turtles with [shape = \"face angry\" or shape = \"girl angry\"]"
"happy" 1.0 0 -13840069 true "" "plot count turtles with [shape = \"face happy\" or shape = \"girl happy\"]"

PLOT
910
10
1147
149
fights and groups
ticks
n
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"fights" 1.0 0 -2674135 true "" "plot fights"
"groups" 1.0 0 -16777216 true "" "plot groups"

SLIDER
192
279
364
312
individualism
individualism
0
100
50.0
10
1
NIL
HORIZONTAL

SLIDER
192
318
364
351
power-distance
power-distance
0
100
50.0
10
1
NIL
HORIZONTAL

TEXTBOX
219
256
347
275
Culture & Trust
16
0.0
1

SLIDER
7
279
179
312
number-people
number-people
0
40
40.0
1
1
NIL
HORIZONTAL

SLIDER
7
358
179
391
initial-status-stdev
initial-status-stdev
0
0.1
0.05
0.01
1
NIL
HORIZONTAL

SLIDER
7
436
179
469
status-deficit-limit
status-deficit-limit
0
2
1.0
0.2
1
NIL
HORIZONTAL

PLOT
1152
10
1394
149
status distribution
status
n
0.0
105.0
0.0
20.0
false
false
"" ""
PENS
"people-pen" 1.0 1 -13345367 true "" "histogram [status * 100] of people"

TEXTBOX
22
256
191
286
Agent initialization
16
0.0
1

TEXTBOX
15
13
197
140
GRASP WORLD\nGert Jan Hofstede \nChutao Liu \n2018\n\n
18
103.0
1

SWITCH
221
187
338
220
new-seed?
new-seed?
1
1
-1000

INPUTBOX
221
119
338
179
current-seed
7.85013024E8
1
0
Number

BUTTON
285
73
348
106
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
192
475
364
508
neighbour-distance
neighbour-distance
1
3
1.5
0.5
1
NIL
HORIZONTAL

SLIDER
7
397
179
430
status-conferral-stdev
status-conferral-stdev
0
0.50
0.25
0.05
1
NIL
HORIZONTAL

SLIDER
192
358
364
391
xenophobia-factor
xenophobia-factor
0
0.25
0.13
0.01
1
NIL
HORIZONTAL

SLIDER
7
475
179
508
win-bonus
win-bonus
0
0.1
0.05
0.01
1
NIL
HORIZONTAL

BUTTON
285
36
348
69
go 300
repeat 300 [ go ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
910
425
1147
546
people alone
ticks
n
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count people with [ alone? ]"

SLIDER
192
397
364
430
dyadic-trust-factor
dyadic-trust-factor
0
1
0.0
0.1
1
NIL
HORIZONTAL

PLOT
910
151
1147
285
average ticks-in-group
ticks
ticks
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean [ticks-in-group] of people"

PLOT
1152
287
1394
423
status differentiation
ticks
max - min
0.0
10.0
0.0
1.2
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "let maximum-status [status] of max-one-of people [status]\nlet minimum-status [status] of min-one-of people [status]\nplot maximum-status - minimum-status"

SLIDER
7
318
179
351
number-shades
number-shades
1
9
5.0
1
1
NIL
HORIZONTAL

TEXTBOX
232
450
348
470
Observation
16
0.0
1

TEXTBOX
17
108
212
228
Legend:\n  size:     social status\n  face:     sex & emotion\n  shade:  norm meme\n  aura size:  group age\n  aura color:  group ID\n
16
0.0
1

PLOT
1152
151
1394
285
average group longevity
ticks
ticks
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "let total-longevity 0\nforeach colors-in-use [c -> let group-longevity (max ([ticks-in-group] of people with [[color] of my-aura = c])) set total-longevity (total-longevity + group-longevity)]\nif length colors-in-use != 0 [\nlet mean-longevity (total-longevity / length colors-in-use)\nifelse ticks = 0 [plotxy 0 0]\n[plot mean-longevity]]"

PLOT
1152
425
1394
546
% happy members in groups
ticks
%
0.0
10.0
30.0
120.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "let total-happy-percent 0\nforeach colors-in-use [c -> let group-happy-percent ((count people with [[color] of my-aura = c and my-emotion = \"happy\"]) / (count people with [[color] of my-aura = c])) set total-happy-percent total-happy-percent + group-happy-percent]\nif length colors-in-use != 0 [ \nlet mean-happy-percent (total-happy-percent / length colors-in-use)\nifelse ticks = 0 [plotxy 0 30]\n[plot mean-happy-percent * 100]]"

@#$#@#$#@
## WHAT IS IT?

This first version of GRASP world is described in a paper for SSC 2018 Stockholm: "Trust, culture and groups in GRASP world: a foundational Agent-Based Model". 

The abstract:

This paper describes an agent-based model that investigates trust issues and the resulting group structure of a population in a foundational way, using theory on culture and trust. The model is an application of the GRASP meta-model for so-cial agents, containing elements of Groups, Rituals, Affiliation, Status, and Pow-er. It can be considered a culture-general, content-free baseline trust model from which to engage in more specific studies. Depending on cultural settings for indi-vidualism and power distance, as well as settings for xenophobia and trust in-crease over group life, the GRASP world model generates a variety of patters. Number of groups ranges from one to many, composition from random to segre-gated, and pattern genesis from rapid to many hundreds of time steps. This makes GRASP world an instrument that plausibly models some basic elements of social structure in different societies


## HOW IT WORKS

People (agents) are visible as smileys. They have a shade of face that indicates their social identity (visible attributes and behaviour) on a one-dimensional scale, and an aura around them that indicates in which group they are and how long they have been in it. When alone, their aura is narrow and grey. they all start alone in tick 0. The people's social status is visible as their size: bigger ones have higher status. At the start, status is normally distributed. Girls have hair, boys do not; this has no role in this model version though.

In each tick, a person tries to find someome to interact with, either by joining one that is alone, or by joining a group. 

Then, they interact in pairs withing groups. They can be in one of three emotional states: neutral, happy, or angry. When alone they are neutral. While interacting, the pair perform mutual 'status conferrals' (according to T.D. Kemper's 'Status-power theory of social relations'). If these are near-equal, both become happy. If they are too unequal, the one that gave the most status will get neutral, or even angry ("I'm so nice to you, and you are not being nice to me back") and may pick up a quarrel.

The chance of getting angry is affected by the difference in shade between the pair, to the extent that the system parameter 'xenophobia-factor' is greater than zero. 

The winner of a fight is likely the one who already has the highest status, and winning will give the winner additional status, while losing takes an equal amount of status away from an agent. The status distribution changes only through win/lose interactions (as in the DomWorld model by Charlotte Hemelrijk).

Thirdly, all agents consider whether they will stay in their group in the next tick, or go find a new group. If they stay, their aura grows, until a maximum size after twenty ticks. Staying is affected by the system parameter 'trust-factor' that determines how much more likely an agent is to stay in a group that it already knows, compared with one in which it has just arrived.

Effect of culture:

All agents have the same culture in this model version. It consists of two dimensions (from the Hofstede work on national culture), modelled as system parameters.

individualism (versus collectivism): the more individualistic the culture, the more likely agents are to leave a group if they are not happy.

power-distance (large vs small) has two effects: 1. leads to submission during interaction so that agents accept lower conferrals from powerful members without becoming angry; 2. leads to agents not leaving groups if there are powerful others in those groups (unless those others leave, in which case the group disbands). So the powerful decide about continued group survival.

## HOW TO USE IT

This model simulates group dynamics in a generzlized way. These dynamics can be expected to apply in all walks of life in a society, e.g. politics, business, family, organizational behaviour. No precise match with particular cases is to be expected though; the agents are too simple for that, and there is no context.

The two culture dimensions have an influence on mobility, and indirectly on happiness. The two factors related to trust (xenpphobia and trust-factor) change the dynamics. Xenohobia, in conjunction with the number of shades and the differences between those shades, is particularly important in determining self-organization.

Fights lead to the establishment of a social hierarchy that can, in extremis, become a two-class society. Depending on power distance, xenophobia and number of shades, this can lead to patterns that stabilize after numbers of ticks in the order of many hundreds, or that destabilize after a comparable time. 

## THINGS TO NOTICE

Since the agents form groups with nearby agents in tick 1, which leads to many groups if there are many agents, achieving one big group requires mobility. individualism and small power distance make this more likely.

The article for SSC Stockholm describes five patterns that the simulation can generate. They range fron 'nothing ever changes' to 'no group ever stays'. In between these two extremes, a variety of self-organised patterrns can obtain.

## THINGS TO TRY

Normally, running with 40 agents is most interesting. But you could try to run the model with two or three agents to see the micro-dynamics of what they do. It works best if in the top bar you select update the view 'continuously' instead of 'on tick' - which means many updates in one tick, so be sure to undo that if you want fast execution.

If you set 'new-seed' on, each new run will use a different set of agents. If you want to remember your agent population and only change a parameter, run the model with 'new-seed' off.

Try corner testing with culture. What happens if power distance varies from 0 to 100? 

Try working with exactly two shades. Can you generate segregated or mixed patterns? What if the shades are more, or less different? What happens when you change the number of shades?

## EXTENDING THE MODEL

Working with a cross-cultural population could be quite interesting.


## NETLOGO FEATURES



## RELATED MODELS

Status-power arena by Gert Jan Hofstede, available on COMSES

DomWorld by Charlotte Hemelrijk

## CREDITS AND REFERENCES

Wageningen University, Information Technology Group, Gert Jan Hofstede & Chutao Liu 2018

Theory inspired by Theodore Kemper's status-power theory & Hofstede's dimensions of culture

related paper to be submitted to JASSS 
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face angry
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183
Polygon -7500403 false true 238 65 51 68 149 116 244 69
Polygon -7500403 true true 151 115 245 68 56 72

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

girl angry
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183
Polygon -7500403 false true 238 65 51 68 149 116 244 69
Polygon -7500403 true true 151 115 245 68 56 72
Polygon -16777216 true false 15 225 45 60 150 45 270 75 285 225 300 180 285 45 150 0 15 45 0 180 15 225

girl happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240
Polygon -16777216 true false 30 240 45 60 150 30 255 60 270 240 300 195 285 30 150 0 15 30 0 210

girl neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225
Polygon -16777216 true false 15 210 45 60 150 45 255 60 285 210 300 165 270 30 150 0 30 30 0 165 15 210

girl sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183
Polygon -16777216 true false 15 225 45 60 150 45 255 60 285 225 300 165 270 30 150 0 30 30 0 165

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Playground 2013 01 23 ESSA 1" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>fight-pickers</metric>
    <metric>hushed-fights</metric>
    <metric>length colors-in-use</metric>
    <metric>count turtles with [my-emotion = "happy"]</metric>
    <metric>count girls with [my-emotion = "happy"]</metric>
    <metric>count boys with [my-emotion = "happy"]</metric>
    <metric>count turtles with [my-emotion = "sad"]</metric>
    <metric>count turtles with [my-emotion = "neutral"]</metric>
    <enumeratedValueSet variable="calling-distance">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="masculinity">
      <value value="0"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-girls">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-boys">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="power-distance">
      <value value="0"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="flight-distance">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="label-turtles?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="individualism">
      <value value="0"/>
      <value value="50"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="uncertainty-avoidance">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Norm-Value SA OFAT - 01" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>fights</metric>
    <metric>groups</metric>
    <metric>standard-deviation ([status] of people)</metric>
    <metric>status-differentiation</metric>
    <metric>count people with [status &gt;= 0.95]</metric>
    <metric>count people with [status &lt;= 0.05]</metric>
    <metric>count people with [my-emotion = "happy"]</metric>
    <metric>count people with [my-emotion = "neutral"]</metric>
    <metric>count people with [my-emotion = "angry"]</metric>
    <metric>count people with [alone?]</metric>
    <metric>group-life-length</metric>
    <metric>happy-percent-in-group</metric>
    <metric>neutral-percent-in-group</metric>
    <metric>angry-percent-in-group</metric>
    <metric>std-of-shades-in-group</metric>
    <metric>std-of-status-in-group</metric>
    <enumeratedValueSet variable="number-boys">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-girls">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-shades">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-status-stdev">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="status-conferral-stdev">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="status-deficit-limit">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="win-bonus">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="individualism">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="power-distance">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="xenophobia-factor">
      <value value="0.15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dyadic-trust-factor">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighbour-distance">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-seed?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
